footings\_test\_module.DocModel
===============================

.. currentmodule:: footings_test_module

.. autoclass:: DocModel

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DocModel.__init__
      ~DocModel.audit
      ~DocModel.run
      ~DocModel.visualize
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DocModel.asset_1
      ~DocModel.asset_2
      ~DocModel.assets
      ~DocModel.meta_1
      ~DocModel.meta_2
      ~DocModel.modif_1
      ~DocModel.modif_2
      ~DocModel.param_1
      ~DocModel.param_2
      ~DocModel.steps
   
   